@@ -15,7 +15,7 @@ class ChessControlHeatmap:
         "Fetches the input from files and starts to analyze the games"
         game_list = ChessUtil.get_games_from_pgn_files()
         dask_cluster = ChessDaskCluster()
-        gamedata_list = dask_cluster.analyse_games_in_cluster(game_list)
-        print("Done calculating heatmap, now generting gifs")
-        pool = multiprocessing.Pool()
-        pool.map(ChessImageGenerator.create_gif, gamedata_list)
+        dask_cluster.analyse_games_in_cluster(game_list)
+        # print("Done calculating heatmap, now generting gifs")
+        # pool = multiprocessing.Pool()
+        # pool.map(ChessImageGenerator.create_gif, gamedata_list)
